@@ -1,6 +1,7 @@
 use crate::install::Tool;
 use anyhow::Result;
 use serde::Deserialize;
+const VERSION: Option<&str> = option_env!("CARGO_PKG_VERSION");
 
 #[derive(Debug, Deserialize)]
 pub struct Krate {
@@ -16,10 +17,17 @@ pub struct KrateResponse {
 impl Krate {
     pub fn new(name: &Tool) -> Result<Krate> {
         let krate_address = format!("https://crates.io/api/v1/crates/{}", name);
-        let client = reqwest::blocking::Client::new();
-        let res = client.get(&krate_address).send()?;
+        let res = ureq::builder()
+            .try_proxy_from_env(true)
+            .build()
+            .get(&krate_address)
+            .set(
+                "user-agent",
+                &format!("wasm-pack/{}", VERSION.unwrap_or("unknown")),
+            )
+            .call()?;
 
-        let kr: KrateResponse = serde_json::from_str(&res.text()?)?;
+        let kr: KrateResponse = res.into_json()?;
         Ok(kr.krate)
     }
 }
