@@ -1,4 +1,5 @@
 use crate::utils::fixture;
+use semver::{Version, VersionReq};
 use wasm_pack::lockfile::Lockfile;
 use wasm_pack::manifest::CrateData;
 
@@ -8,7 +9,7 @@ fn it_gets_wasm_bindgen_version() {
     fixture.cargo_check();
     let data = CrateData::new(&fixture.path, None).unwrap();
     let lock = Lockfile::new(&data).unwrap();
-    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.74"),);
+    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.100"),);
 }
 
 #[test]
@@ -17,7 +18,8 @@ fn it_gets_wasm_bindgen_test_version() {
     fixture.cargo_check();
     let data = CrateData::new(&fixture.path, None).unwrap();
     let lock = Lockfile::new(&data).unwrap();
-    assert_eq!(lock.wasm_bindgen_test_version(), Some("0.3.24"),);
+    let ver = Version::parse(lock.wasm_bindgen_test_version().unwrap()).unwrap();
+    assert!(VersionReq::parse("0.3").unwrap().matches(&ver));
 }
 
 #[test]
@@ -39,14 +41,14 @@ fn it_gets_wasm_bindgen_version_in_crate_inside_workspace() {
                 description = "so awesome rust+wasm package"
                 license = "WTFPL"
                 name = "blah"
-                repository = "https://github.com/rustwasm/wasm-pack.git"
+                repository = "https://github.com/drager/wasm-pack.git"
                 version = "0.1.0"
 
                 [lib]
                 crate-type = ["cdylib"]
 
                 [dependencies]
-                wasm-bindgen = "=0.2.74"
+                wasm-bindgen = "=0.2.100"
             "#,
         )
         .file(
@@ -62,7 +64,7 @@ fn it_gets_wasm_bindgen_version_in_crate_inside_workspace() {
     fixture.cargo_check();
     let data = CrateData::new(&fixture.path.join("blah"), None).unwrap();
     let lock = Lockfile::new(&data).unwrap();
-    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.74"),);
+    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.100"),);
 }
 
 #[test]
@@ -84,14 +86,14 @@ fn it_gets_wasm_bindgen_version_from_dependencies() {
                 description = "so awesome rust+wasm package"
                 license = "WTFPL"
                 name = "child"
-                repository = "https://github.com/rustwasm/wasm-pack.git"
+                repository = "https://github.com/drager/wasm-pack.git"
                 version = "0.1.0"
 
                 [lib]
                 crate-type = ["cdylib"]
 
                 [dependencies]
-                wasm-bindgen = "=0.2.74"
+                wasm-bindgen = "=0.2.100"
             "#,
         )
         .file(
@@ -112,7 +114,7 @@ fn it_gets_wasm_bindgen_version_from_dependencies() {
                 description = "so awesome rust+wasm package"
                 license = "WTFPL"
                 name = "parent"
-                repository = "https://github.com/rustwasm/wasm-pack.git"
+                repository = "https://github.com/drager/wasm-pack.git"
                 version = "0.1.0"
 
                 [lib]
@@ -130,5 +132,5 @@ fn it_gets_wasm_bindgen_version_from_dependencies() {
     fixture.cargo_check();
     let data = CrateData::new(&fixture.path.join("parent"), None).unwrap();
     let lock = Lockfile::new(&data).unwrap();
-    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.74"),);
+    assert_eq!(lock.wasm_bindgen_version(), Some("0.2.100"),);
 }
